@@ -287,7 +287,7 @@ public abstract class Page implements Serializable {
 	 * @return 変化があったコントロール全て。
 	 * 何も変更されずにサブミットされていれば、0個の配列を返します。
 	 */
-	public Control[] getModified() {
+	public Control[] getModifiedControl() {
 		return modified;
 	}
 
@@ -897,6 +897,29 @@ public abstract class Page implements Serializable {
 	public void beginning( RequestParameter req ) throws PageException {
 		if ( beginning_called )	return;
 		beginning_called = true;
+		Tag	head = getFirstTagByType( "head" );
+		if ( head != null ) {
+			int	idx = 0;
+			int	max = head.getHTMLPartCount();
+			for ( ; idx < max; idx++ ) {
+				HTMLPart	part = head.getHTMLPart( idx );
+				if ( !(part instanceof Tag) )	continue;
+				Tag	tag = (Tag)part;
+				if ( "link".equals( tag.getName() ) )	break;
+			}
+			try {
+				Tag	tag = new Tag( "link", true );
+				tag.setAttribute(
+					new Attribute( "rel", new Text( "stylesheet" ) ),
+					new Attribute( "href", new URIValue( "paraselene.css.na" ) ),
+					new Attribute( "type", new Text( "text/css" ) )
+				);
+				head.addHTMLPart( idx, tag );
+			}
+			catch( Exception e ){
+				Option.debug( e );
+			}
+		}
 		firstOutput( req );
 	}
 }
