@@ -100,7 +100,6 @@ public class Text extends PlainText implements AttributeValuable, CSSValuable {
 		StringBuilder	buf = new StringBuilder();
 		StringBuilder	esc = null;
 		int	spc_cnt = 0;
-		boolean	nbsp_f = false;
 		for ( int i = 0; i < line.length; i++ ) {
 			if ( line[i] == '\n' || line[i] == '\r' ) {
 				if ( i > 0 ) {
@@ -120,15 +119,7 @@ public class Text extends PlainText implements AttributeValuable, CSSValuable {
 				continue;
 			}
 			if ( spc_cnt > 0 ) {
-				if ( mode == StringMode.TABLE ) {
-					if ( nbsp_f ) {
-						buf = buf.append( ' ' );
-						nbsp_f = false;
-					}
-				}
-				else {
-					buf = buf.append( ' ' );
-				}
+				buf = buf.append( ' ' );
 				spc_cnt = 0;
 			}
 			if ( esc != null ) {
@@ -149,7 +140,6 @@ public class Text extends PlainText implements AttributeValuable, CSSValuable {
 				}
 				else if ( "&nbsp;".equalsIgnoreCase( amp ) ) {
 					buf = buf.append( ' ' );
-					nbsp_f = true;
 				}
 				else {
 					buf = buf.append( esc );
@@ -157,14 +147,12 @@ public class Text extends PlainText implements AttributeValuable, CSSValuable {
 				esc = null;
 				continue;
 			}
-			nbsp_f = false;
 			if ( line[i] == '&' ) {
 				esc = new StringBuilder( "&" );
 				continue;
 			}
 			spc_cnt = 0;
 			buf = buf.append( line[i] );
-			nbsp_f = false;
 		}
 		if ( esc != null ) {
 			buf = buf.append( esc );
@@ -189,7 +177,6 @@ public class Text extends PlainText implements AttributeValuable, CSSValuable {
 			if ( line[i] == ' ' ) {
 				String	add = " ";
 				switch( mode ) {
-				case TABLE:
 				case BODY:
 					add = ((spc_cnt % 2) == 0)?	"&nbsp;": " ";
 					break;
