@@ -16,7 +16,7 @@ import paraselene.mockup.*;
  * スタイルシート宣言。
  */
 public class Property implements Serializable {
-	private static final long serialVersionUID = 1L;
+	private static final long serialVersionUID = 2L;
 	/**
 	 * !importantの文字列。
 	 */
@@ -52,14 +52,15 @@ public class Property implements Serializable {
 	/**
 	 * 宣言部の解析。
 	 * @param str 宣言文字列。
+	 * @param dec URLがあった場合のデコード文字コード。
 	 */
-	public static Property[] create( String str ) {
+	public static Property[] create( String str, String dec ) {
 		str = str.trim();
 		ArrayList<Property>	ret = new ArrayList<Property>();
 		String[]	line = CSSParser.split( str, ';' );
 		for ( int i = 0; i < line.length; i++ ) {
-			String[]	part = CSSParser.split( str, ':' );
-			ret.add( new Property( part[0], part[1] ) );
+			String[]	part = CSSParser.split( line[i], ':' );
+			ret.add( new Property( part[0].trim(), part[1].trim(), dec ) );
 		}
 		return ret.toArray( new Property[0] );
 	}
@@ -70,11 +71,12 @@ public class Property implements Serializable {
 	 * @param important true:important指定、false:importantではない。
 	 * @param n 属性名。
 	 * @param v 属性値。
+	 * @param dec URLがあった場合のデコード文字コード。
 	 */
-	public Property( boolean important, String n, String v ) {
+	public Property( boolean important, String n, String v, String dec ) {
 		setImportant( important );
 		setName( n );
-		set( v );
+		set( v, dec );
 	}
 
 	/**
@@ -82,9 +84,10 @@ public class Property implements Serializable {
 	 * importantは指定されません。
 	 * @param n 属性名。
 	 * @param v 属性値。
+	 * @param dec URLがあった場合のデコード文字コード。
 	 */
-	public Property( String n, String v ) {
-		this( false, n, v );
+	public Property( String n, String v, String dec ) {
+		this( false, n, v, dec );
 	}
 
 	/**
@@ -144,14 +147,15 @@ public class Property implements Serializable {
 	/**
 	 * 属性値の設定。
 	 * @param v 属性値。
+	 * @param dec URLがあった場合のデコード文字コード。
 	 */
-	public void set( String v ) {
+	public void set( String v, String dec ) {
 		if ( v == null ) {
 			value = null;
 			return;
 		}
 		String[]	str = CSSParser.split( CSSParser.split( v, ';' )[0], ' ' );
-		ArrayList<Text>	list = new ArrayList<Text>();
+		ArrayList<CSSValuable>	list = new ArrayList<CSSValuable>();
 		for ( int i = 0; i < str.length; i++ ) {
 			str[i] = str[i].trim();
 			if ( str[i].isEmpty() )	continue;
@@ -165,9 +169,9 @@ public class Property implements Serializable {
 				setImportant( true );
 				continue;
 			}
-			list.add( new Text( str[i] ) );
+			list.add( Converter.toCSSValuable( str[i], dec ) );
 		}
-		set( list.toArray( new Text[0] ) );
+		set( list.toArray( new CSSValuable[0] ) );
 	}
 
 	/**
