@@ -30,12 +30,16 @@ public class Converter {
 		"charoff", "span", "colspan", "rowspan",
 		"left", "pagex", "pagey", "top", "z-index", "loop",
 		"scrollamount", "scrolldelay",
-		"cols", "gutter",
+		"gutter",
 		"cellpadding", "cellspacing", "datapagesize",
-		"maxlength", "rows",
+		"maxlength",
+	};
+	private static String[] mul_name = new String[] {
+		"cols", "rows", "clip",
 	};
 	private static HashMap<String,String>	uri_map = new HashMap<String,String>();
 	private static HashMap<String,String>	len_map = new HashMap<String,String>();
+	private static HashMap<String,String>	mul_map = new HashMap<String,String>();
 	private static HashMap<String,String>	clr_map = new HashMap<String,String>();
 	static {
 		for ( int i = 0; i < uri_name.length; i++ ) {
@@ -44,6 +48,9 @@ public class Converter {
 		for ( int i = 0; i < len_name.length; i++ ) {
 			len_map.put( len_name[i], len_name[i] );
 		}
+		for ( int i = 0; i < mul_name.length; i++ ) {
+			mul_map.put( mul_name[i], mul_name[i] );
+		}
 		for ( int i = 0; i < clr_name.length; i++ ) {
 			clr_map.put( clr_name[i], clr_name[i] );
 		}
@@ -65,6 +72,9 @@ public class Converter {
 	static boolean isNumber( String n ) {
 		return ( len_map.get( n.toLowerCase( Locale.ENGLISH ) ) != null );
 	}
+	static boolean isMultiNumber( String n ) {
+		return ( mul_map.get( n.toLowerCase( Locale.ENGLISH ) ) != null );
+	}
 	/**
 	 * 色属性であるか？
 	 * @param n 属性名。
@@ -77,53 +87,88 @@ public class Converter {
 		return "style".equals( n.toLowerCase( Locale.ENGLISH ) );
 	}
 
-	public static AttributeValuable toAttributeValuable( String name, Valuable v, String dec ) {
-		AttributeValuable	txt = toAttributeValuable( v );
-		if ( txt == null )	return null;
-		if ( isURI( name ) ) {
-			if ( txt instanceof URIValue )	return txt;
-			try {
-				return new URIValue( txt.toString() );
+	public static AttributeValuable[] toAttributeValuable( String name, Valuable[] v, String dec ) {
+		AttributeValuable[]	ret = new AttributeValuable[v.length];
+		for ( int i = 0; i < v.length; i++ ) {
+			AttributeValuable	txt = toAttributeValuable( v[i] );
+			if ( txt == null )	return null;
+			if ( isURI( name ) ) {
+				if ( txt instanceof URIValue ) {
+					ret[i] = txt;
+					continue;
+				}
+				try {
+					ret[i] = new URIValue( txt.toString() );
+					continue;
+				}
+				catch( Exception e ) {
+					Option.debug( e );
+				}
 			}
-			catch( Exception e ) {
-				Option.debug( e );
+			else if ( isNumber( name ) || isMultiNumber( name ) ) {
+				if ( txt instanceof NumberValue ) {
+					ret[i] = txt;
+					continue;
+				}
+				ret[i] = new NumberValue( txt.toString() );
+				continue;
 			}
+			else if ( isColor( name ) ) {
+				if ( txt instanceof Color ) {
+					ret[i] = txt;
+					continue;
+				}
+				ret[i] = new Color( txt.toString() );
+				continue;
+			}
+			else if ( isStyle( name ) ) {
+				if ( txt instanceof Style ) {
+					ret[i] = txt;
+					continue;
+				}
+				ret[i] = new Style( Property.create( txt.toString(), dec ) );
+				continue;
+			}
+			ret[i] = txt;
 		}
-		else if ( isNumber( name ) ) {
-			if ( txt instanceof NumberValue )	return txt;
-			return new NumberValue( txt.toString() );
-		}
-		else if ( isColor( name ) ) {
-			if ( txt instanceof Color )	return txt;
-			return new Color( txt.toString() );
-		}
-		else if ( isStyle( name ) ) {
-			if ( txt instanceof Style )	return txt;
-			return new Style( Property.create( txt.toString(), dec ) );
-		}
-		return txt;
+		return ret;
 	}
 
-	public static AttributeValuable toAttributeValuable( String name, String txt, String dec ) {
+	public static AttributeValuable[] toAttributeValuable( String name, String txt, String dec ) {
 		if ( txt == null )	return null;
-		if ( isURI( name ) ) {
-			try {
-				return new URIValue( txt );
+		String[]	part = null;
+		if ( isMultiNumber( name ) ) {
+			part = txt.split( "," );
+		}
+		else {
+			part = new String[]{ txt };
+		}
+		AttributeValuable[]	ret = new AttributeValuable[part.length];
+		for ( int  i = 0; i < part.length; i++ ) {
+			if ( isURI( name ) ) {
+				try {
+					ret[i] = new URIValue( part[i] );
+					continue;
+				}
+				catch( Exception e ) {
+					Option.debug( e );
+				}
 			}
-			catch( Exception e ) {
-				Option.debug( e );
+			else if ( isNumber( name ) || isMultiNumber( name ) ) {
+				ret[i] = new NumberValue( part[i] );
+				continue;
 			}
+			else if ( isColor( name ) ) {
+				ret[i] = new Color( part[i] );
+				continue;
+			}
+			else if ( isStyle( name ) ) {
+				ret[i] = new Style( Property.create( part[i], dec ) );
+				continue;
+			}
+			ret[i] = new Text( part[i] );
 		}
-		else if ( isNumber( name ) ) {
-			return new NumberValue( txt );
-		}
-		else if ( isColor( name ) ) {
-			return new Color( txt );
-		}
-		else if ( isStyle( name ) ) {
-			return new Style( Property.create( txt, dec ) );
-		}
-		return new Text( txt );
+		return ret;
 	}
 
 	private static AttributeValuable toAttributeValuable( Valuable v ) {
