@@ -84,6 +84,22 @@ public abstract class Output {
 		return buf.toString();
 	}
 
+	private static String stripLine( String str ) {
+		char[]	ch = str.toCharArray();
+		StringBuilder	buf = new StringBuilder();
+		for ( int i = 0; i < ch.length; i++ ) {
+			if ( ch[i] == '\n' || ch[i] == '\r' ) {
+				continue;
+			}
+			buf.append( ch[i] );
+		}
+		return buf.toString();
+	}
+
+	public InputStream getInputStream( String chset ) throws UnsupportedEncodingException {
+		return new ByteArrayInputStream( stripLine( getFileByte() ).getBytes( chset ) );
+	}
+
 	public Status write( File file, OutputNo out_no, long org_tm ) throws Exception {
 		if ( org_tm > 0  && file.exists() ) {
 			if ( file.lastModified() > org_tm )	return Status.SKIP;
