@@ -22,7 +22,7 @@ public class RequestParameter {
 	public enum Method {
 		GET, POST;
 
-		private static final long serialVersionUID = 1L;
+		private static final long serialVersionUID = 2L;
 	}
 
 	/**
@@ -77,6 +77,63 @@ public class RequestParameter {
 		return Mobile.NO_MOBILE;
 	}
 
+	/**
+	 * 検索エンジンクローラー。
+	 */
+	public enum SearchEngine {
+		/**
+		 * Google AdSense。
+		 * Google AdSense の掲載広告選定用クローラー
+		 * (ページの文言を解析して、適した掲載広告を決定します)です。
+		 * Google の検索結果自体には影響しません。
+		 */
+		GOOGLE_ADSENSE( "mediapartners-google" ),
+		/**
+		 * Google。
+		 * Google の検索結果自体に反映するためのクローラーです。
+		 */
+		GOOGLE( "googlebot" ),
+		/**
+		 * Yahoo!。
+		 */
+		YAHOO( "yahoo!", "slurp" ),
+		/**
+		 * bing。
+		 */
+		MSN( "msnbot" ),
+		/**
+		 * 百度。
+		 */
+		BAIDU( "baiduspider" ),
+		/**
+		 * 検索エンジンではない。
+		 */
+		NO_SEARCHENGINE();
+		private String[]	str = null;
+		private SearchEngine( String ... s ) { str = s; }
+		boolean isHit( String ua ) {
+			if ( str == null )	return true;
+			for ( int i = 0; i < str.length; i++ ) {
+				if ( ua.indexOf( str[i] ) == -1 )	return false;
+			}
+			return true;
+		}
+	}
+	/**
+	 * ユーザーエージェントから、検索エンジンクローラーを判定する。
+	 * @param ua ユーザーエージェント。nullなら、NO_SEARCHENGINEを返します。
+	 * @return 判定結果。
+	 */
+	public static SearchEngine judgSearchEngine( String ua ) {
+		if ( ua == null )	return SearchEngine.NO_SEARCHENGINE;
+		SearchEngine[]	dim = SearchEngine.values();
+		ua = ua.toLowerCase( Locale.ENGLISH );
+		for ( int i = 0; i < dim.length; i++ ) {
+			if ( dim[i].isHit( ua ) )	return dim[i];
+		}
+		return SearchEngine.NO_SEARCHENGINE;
+	}
+
 	private HashMap<String,RequestItem>	item_map = new HashMap<String,RequestItem>();
 	private Method	method;
 	private URI	uri = null;
@@ -98,6 +155,17 @@ public class RequestParameter {
 		return judgMobile( ua[0] );
 	}
 
+	/**
+	 * ユーザーエージェントから、携帯キャリアを判定する。
+	 * @return 判定結果。
+	 */
+	public SearchEngine judgSearchEngine() {
+		String[]	ua = getHeader( UA_HEAD );
+		if ( ua == null )	return SearchEngine.NO_SEARCHENGINE;
+		if ( ua.length < 1 )	return SearchEngine.NO_SEARCHENGINE;
+		return judgSearchEngine( ua[0] );
+	}
+
 	/**
 	 * コンストラクタ。
 	 */
