@@ -145,6 +145,7 @@ public abstract class Supervisor extends HttpServlet {
 		if ( holder.search_engine )	return URIValue.encode( uri, enc );
 		String[]	part = uri.split( "/" );
 		boolean	flag = false;
+		String	head = null;
 		for ( int i = 0; i < part.length; i++ ) {
 			int	def_no;
 			for ( def_no = 0; def_no < LINK_DEF.length; def_no++ ) {
@@ -160,19 +161,27 @@ public abstract class Supervisor extends HttpServlet {
 				break;
 			case 1:
 			case 2:
-				part[i] = resolveHost( holder, part[i], def_no );
+				head = resolveHost( holder, part[i], def_no );
+				part[i] = "";
 				break;
 			}
 		}
 		if ( flag ) {
 			StringBuilder	buf = new StringBuilder( part[0] );
 			for ( int i = 1; i < part.length; i++ ) {
-				buf = buf.append( "/" );
+				if ( buf.length() > 0 )	buf = buf.append( "/" );
 				buf = buf.append( part[i] );
 			}
 			uri = buf.toString();
 		}
-		return holder.response.encodeURL( URIValue.encode( uri, enc ) );
+		uri = holder.response.encodeURL( URIValue.encode( uri, enc ) );
+		if ( head != null ) {
+			StringBuilder	buf = new StringBuilder( head );
+			buf = buf.append( "/" );
+			buf = buf.append( uri );
+			uri = buf.toString();
+		}
+		return uri;
 	}
 
 	/**
@@ -188,12 +197,12 @@ public abstract class Supervisor extends HttpServlet {
 	 */
 	public abstract void onError( Throwable e );
 
-	private Forward onErrorDebug( Throwable e, HttpServletRequest req, HttpServletResponse res ) {
+	private Forward onErrorDebug( Throwable e, HttpServletRequest req, HttpServletResponse res, int status ) {
 		if ( e instanceof Page.PageException ) {
 			Page.PageException	pe = (Page.PageException)e;
 			e = pe.get();
 		}
-		Forward fw = new Forward( 500 );
+		Forward fw = new Forward( status );
 		e.printStackTrace();
 		onError( e );
 		try {
@@ -212,6 +221,9 @@ public abstract class Supervisor extends HttpServlet {
 		}
 		return fw;
 	}
+	private Forward onErrorDebug( Throwable e, HttpServletRequest req, HttpServletResponse res ) {
+		return onErrorDebug( e, req, res, 500 );
+	}
 
 	/**
 	 * 不正呼び出しの検出通知。
@@ -676,7 +688,7 @@ public abstract class Supervisor extends HttpServlet {
 			req = parseRequest( request, p );
 		}
 		catch( Exception e ){
-			return onErrorDebug( e, request, res );
+			return onErrorDebug( e, request, res, 422 );
 		}
 		req.setParam( method, request, this );
 		holder.search_engine = req.judgSearchEngine() != RequestParameter.SearchEngine.NO_SEARCHENGINE;
@@ -694,6 +706,13 @@ public abstract class Supervisor extends HttpServlet {
 	}
 
 	RequestParameter parseRequest( HttpServletRequest request, PathData p ) throws Exception {
+		String	head = request.getHeader( "Content-Type" );
+		if ( head != null ) {
+			head = head.split( ";" )[0];
+			if ( paraselene.tag.form.Form.MULTI_PART.equals( head ) ) {
+				throw new Exception( "Gate class must extend UploadableSupervisor!" );
+			}
+		}
 		return normalReq( request );
 	}
 
