@@ -20,21 +20,29 @@ import paraselene.mockup.*;
 public class Attribute implements Serializable {
 	private static final long serialVersionUID = 2L;
 	private String	name;
-	private AttributeValuable	value;
+	private AttributeValuable[]	value = null;
 	private Page	embed;
 
 	protected Attribute() {}
 
 	synchronized void setPage( Page p ) {
 		embed = p;
-		if ( value != null )	value.setPage( p );
+		if ( value != null ) {
+			for ( int i = 0; i < value.length; i++ ) {
+				value[i].setPage( p );
+			}
+		}
 	}
 	/**
 	 * 複製の作成。
 	 * @return 複製。
 	 */
 	public Attribute getReplica() {
-		return new Attribute( name, value.getValuableReplica() );
+		AttributeValuable[]	attr = new AttributeValuable[value.length];
+		for ( int  i = 0; i < attr.length; i++ ) {
+			attr[i] = (AttributeValuable)value[i].getValuableReplica();
+		}
+		return new Attribute( name, attr );
 	}
 
 	/**
@@ -66,6 +74,16 @@ public class Attribute implements Serializable {
 		set( v );
 	}
 
+	/**
+	 * コンストラクタ。nは小文字に変換される。
+	 * @param n 属性名。
+	 * @param v 属性値。
+	 */
+	public Attribute( String n, Valuable ... v ) {
+		setName( n );
+		set( v );
+	}
+
 	/**
 	 * 属性名の設定。nは小文字に変換される。
 	 * @param n 属性名。
@@ -93,10 +111,10 @@ public class Attribute implements Serializable {
 
 	/**
 	 * 属性値の設定。
-	 * @param v 属性値。
 	 * @param dec URIデコード文字コード。
+	 * @param v 属性値。
 	 */
-	public void set( String v, String dec ) {
+	public void set( String dec, String v ) {
 		value = Converter.toAttributeValuable( getName(), v, dec );
 		setPage( embed );
 	}
@@ -106,16 +124,35 @@ public class Attribute implements Serializable {
 	 * @param v 属性値。
 	 */
 	public void set( Valuable v ) {
-		value = Converter.toAttributeValuable( getName(), v, null );
+		value = Converter.toAttributeValuable( getName(), new Valuable[]{v}, null );
+		setPage( embed );
+	}
+
+	/**
+	 * 属性値の設定。
+	 * @param dec URIデコード文字コード。
+	 * @param v 属性値。
+	 */
+	public void set( String dec, Valuable v ) {
+		value = Converter.toAttributeValuable( getName(), new Valuable[]{v}, dec );
 		setPage( embed );
 	}
 
 	/**
 	 * 属性値の設定。
 	 * @param v 属性値。
-	 * @param dec URIデコード文字コード。
 	 */
-	public void set( Valuable v, String dec ) {
+	public void set( Valuable ... v ) {
+		value = Converter.toAttributeValuable( getName(), v, null );
+		setPage( embed );
+	}
+
+	/**
+	 * 属性値の設定。
+	 * @param dec URIデコード文字コード。
+	 * @param v 属性値。
+	 */
+	public void set( String dec, Valuable ... v ) {
 		value = Converter.toAttributeValuable( getName(), v, dec );
 		setPage( embed );
 	}
@@ -124,18 +161,27 @@ public class Attribute implements Serializable {
 	 * 属性値の取得。
 	 * @return 属性値。無ければnull。
 	 */
-	public AttributeValuable get() {
+	public AttributeValuable[] getAll() {
 		return value;
 	}
 
+	/**
+	 * 最初に存在する属性値の取得。
+	 * @return 属性値。無ければnull。
+	 */
+	public AttributeValuable get() {
+		AttributeValuable[]	ret = getAll();
+		if ( ret == null )	return null;
+		if ( ret.length < 1 )	return null;
+		return ret[0];
+	}
+
 	/**
 	 * 属性値の取得。文字列で返します。
 	 * @return 属性値。無ければnull。
 	 */
 	public String getString() {
-		AttributeValuable	t = get();
-		if ( t == null )	return null;
-		return t.toString( HTMLPart.StringMode.ATTRIBUTE );
+		return getValueString();
 	}
 
 	/**
@@ -143,8 +189,15 @@ public class Attribute implements Serializable {
 	 * @return 値を出力用に正規化したもの。
 	 */
 	protected String getValueString() {
-		if ( value == null )	return null;
-		return value.toString( HTMLPart.StringMode.ATTRIBUTE );
+		AttributeValuable[]	v = getAll();
+		if ( v == null )	return null;
+		if ( v.length < 1 )	return null;
+		StringBuilder	buf = new StringBuilder( v[0].toString( HTMLPart.StringMode.ATTRIBUTE ) );
+		for ( int  i = 1; i < v.length; i++ ) {
+			buf = buf.append( "," );
+			buf = buf.append( v[i].toString( HTMLPart.StringMode.ATTRIBUTE ) );
+		}
+		return buf.toString();
 	}
 
 	/**
