@@ -474,9 +474,6 @@ public class Tag extends HTMLPart {
 		if ( "textarea".equals( tag_name ) || "pre".equals( tag_name ) ) {
 			mode = StringMode.TEXTAREA;
 		}
-		else if ( "td".equals( tag_name ) || "th".equals( tag_name ) ) {
-			mode = StringMode.TABLE;
-		}
 		else if ( isPlainTag( tag_name ) ) {
 			mode = StringMode.PLAIN;
 		}
